@@ -49,7 +49,9 @@ def autodoc_process_docstring(app, what, name, obj, options, lines):
 
     idx = _tempdata(app)
 
-    docname = app.env.temp_data["docname"]
+    docname = app.env.temp_data.get("docname")
+    if not docname:
+        return
     if docname in idx:
         doc_idx = idx[docname]
     else:
@@ -292,3 +294,8 @@ def setup(app):
     app.connect("build-finished", copy_stylesheet)
     app.connect("missing-reference", lookup_params)
     app.connect("doctree-read", build_index)
+    return {
+        "parallel_read_safe": True,
+        "parallel_write_safe": True,
+    }
+
